%This file solves the steady state CE with permanent types.
%Calibrates beta, phi, omega and nu.

%clc
clear all
%warning off all


global sigma gamma beta taul taus taue beta de ds u up v vp z lambda alpha eta omega rho nu ps phi gy

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
gy = 0.16; %share of G in Y
sigma = 2;%CRRA utility in consumption
gamma = 1;

%eta = .79; %He, Liu (2008)
eta = .401; %KORV
rho = -.495;%KORV and He, Liu (2008)
%rho = eta;
%alpha = .13; %%He, Liu (2008)
alpha = .117; %%KORV
%omega = .491; %He, Liu (2008)
%nu = 1-.423; %He, Liu (2008)

de = .124;%GHK
ds = .056;%GHK

%taxes as in HSV and He and Liu
taul = 0.27;
%taus = 0.4;
%taue = 0.4;
taus = 1-.85*(1-.32);
taue = 1-.85*(1-.26);

%taul = 0;
%tauk = 0;

%utility
if sigma == 1
   u  = @(c) log(c);
   up = @(c) 1./c;
else
    u  = @(c) c.^(1-sigma)./(1-sigma);
    up = @(c) c.^-sigma;
end

%measure of skilled agents
pratio = .778;
ps = pratio/(pratio+1);
pu = 1-ps;

%share in asset holdings of the skilled
wratio = 2.68;
lambda = wratio*ps/(wratio*ps+pu);

%initial guess

y0 = [2, 0.3, 0.6, .98];
%load y
%y0 = y;
options = optimset('display', 'iter','tolfun', 10^(-10), 'tolX', 10^(-10), 'maxfunevals', 10000,'maxiter', 100);%
%options = optimset('display', 'iter', 'tolfun', 10^(-10), 'tolX', 10^(-10), 'maxfunevals', 1000000, 'maxiter', 1000000, 'NonlEqnAlgorithm', 'gn'); 
%options = optimset('display', 'iter', 'tolfun', 10^(-10), 'tolX', 10^(-10), 'maxfunevals', 1000000, 'maxiter', 1000000, 'NonlEqnAlgorithm', 'lm'); 
%options = optimset('display', 'iter', 'tolfun', 10^(-10), 'tolX', 10^(-10), 'maxfunevals', 1000000, 'maxiter', 1000000, 'largescale', 'on'); 
y = fsolve(@calib4, y0, options);
%sum(sum(abs(calib(y))))
y
save y y

%computing the allocations for calibrated z and phi

phi = y(1);
z = [1 1];
omega = y(2);
nu = y(3);
beta = y(4);

load x
x0 = x;
options = optimset('display', 'iter','tolfun', 10^(-20), 'tolX', 10^(-20), 'maxfunevals', 1000000,'maxiter', 1000000);%   
x = fsolve(@systemSSCE, x0, options);
%sum(sum(abs(systemSSCE(x))))

save x x


cs = x(1);
cu = x(2);
Cs = cs*ps;
Cu = cu*(1-ps);
ls = x(3);
lu = x(4);
Ls = z(2)*ls*ps;
Lu = z(1)*lu*(1-ps);
as = x(5);
au = x(6);
As = as*ps;
Au = au*(1-ps);
Ke = x(7);
Ks = x(8);

MP = ycompprime([Ks, Ke, Lu, Ls]);
rs = MP(:,1);
re = MP(:,2);
wu = MP(:,3)*z(1);
ws = MP(:,4)*z(2);
skillp = ws/wu;
earp = ws*ls/(wu*lu);

Y = ycomp([Ks, Ke, Lu, Ls]);
labor = ls*ps+lu*(1-ps);
lshare = (MP(3)*Lu + MP(4)*Ls)/Y;
KY = (Ke+Ks)/Y;
Kratio = Ke/(Ke+Ks);
%government expenditure check;
G = Y - Cs - Cu - de*Ke - ds*Ks;
G - gy*Y


%transfers
T = MP(4)*Ls*taul + MP(3)*Lu*taul + (MP(1) - ds)*Ks*taus +  (MP(2) - de)*Ke*taue - G;
%average taxes
ats  = (taul*(ws*ls)-T)/(ws*ls);
atu  = (taul*(wu*lu)-T)/(wu*lu);
%tax revenues
ltax = (MP(4)*Ls*taul + MP(3)*Lu*taul - T)/G;
ctax = ((MP(1) - ds)*Ks*taus +  (MP(2) - de)*Ke*taue)/G;

corptax = ((1-(1-taus)/.85)*(MP(1) - ds)*Ks + (1-(1-taue)/.85)*(MP(2) - de)*Ke)/(ctax*G);


vls = v(ls)/(1-beta);
vlu = v(lu)/(1-beta);
ucs = u(cs)/(1-beta);
ucu = u(cu)/(1-beta);
values = ucs-vls;
valueu = ucu-vlu;

phis = 1;
value = phis*ps*(ucs-vls) + pu*(ucu-vlu);
input = [phi, z(1), Ke, Ks, beta, eta, rho, alpha, omega, nu, sigma, gamma, G];

%capital return wedge
capitalw = (re + 1 - de)./(rs + 1 - ds) - 1;
%intra wedges unskilled
intrau = 1-vp(lu)./(up(cu).*wu);
%intra wedges skilled
intras = 1-vp(ls)./(up(cs).*ws);
%interwedges
interksu = 1 - 1/(beta*(rs+1-ds));
interkeu = 1 - 1/(beta*(re+1-de));
interksualt = 1-(1/beta-1)/(rs-ds);
interkeualt = 1-(1/beta-1)/(re-de);

save input input
output = [lambda, beta, alpha, eta, rho omega, nu, ucs, ucu, vls, vlu, values, valueu, value, phi, sigma, gamma, ...
    Ke, Ks, Y, (Ke+Ks)/Y, cs, cu, ls, lu, ls*ps + lu*pu, ws, wu, skillp, earp, lshare,...
    G, gy, T, T/Y, ats, atu, ltax, ctax, corptax,  ...
    capitalw, intrau, intras, interkeu, interksu, interkeualt, interksualt]';