function foc = SystemDynamic(x)

%this system uses exact derivatives
%it assumes that only local downward IC binds

global zu zs pu ps T w ke1 ks1 y r beta alpha eta omega rho nu u up v vp de ds k3 G phis

cs = x(1:T+1);
cu = x(T+2: 2*(T+1));
ls = x(2*T+3: 3*(T+1));
lu = x(3*T+4: 4*(T+1));

kspol =  x(4*(T+1)+ 1: 4*(T+1)+T);
kepol =  x(4*(T+1)+ T + 1: 4*(T+1)+2*T);
ks = [ks1; kspol];
ke = [ke1; kepol];
lambda = x(4*(T+1)+2*T+ 1:5*(T+1)+2*T);
mu = x(5*(T+1)+2*T+1);

foc = zeros(7*T+6,1);

%aggregates
Lu = pu*zu*lu;
Ls = ps*zs*ls;
Cu = pu*cu;
Cs = ps*cs;

MP = ycompprime([ks, ke, Lu, Ls]);

rs = MP(:,1);
re = MP(:,2);
wu = MP(:,3)*zu;
ws = MP(:,4)*zs;

der = ycompdprime([ke, lu, ls]);

%FOC wrt c starting with the high type
foc(1:T+1) = up(cs)*(phis*ps+mu) - ps*lambda;
foc(T+2: 2*(T+1)) = up(cu)*(pu-mu) - pu*lambda;

%FOC wrt l starting with the high type
foc(2*T+3: 3*(T+1)) = -phis*ps*vp(ls) + ps*lambda.*ws +mu*(-vp(ls) + vp(lu.*wu./ws).*der(:,3));
foc(3*T+4: 4*(T+1)) = -pu*vp(lu) + pu*lambda.*wu +mu*vp(lu.*wu./ws).*der(:,2);

%steady state FOC is a bit different, need to account for the (1-beta) term
%betainf = [zeros(T-1,1); beta];
%FOC wrt capitals 
%foc(4*(T+1)+ 1: 4*(T+1)+T) = - lambda(1:T).*(1-betainf)  + beta*lambda(2:T+1).*(rs(2:T+1) + 1-ds);
%check1 = foc(4*(T+1)+ 1: 4*(T+1)+T)
%alternative procedure, ks(steady state) is pinned down by SS conditions
foc(4*(T+1)+ 1: 4*(T+1)+T-1) = - lambda(1:T-1)  + beta*lambda(2:T).*(rs(2:T) + 1-ds);
%foc(4*(T+1)+T) = beta*(rs(T+1) + 1-ds)-1;
foc(4*(T+1)+T) = beta^T/(1-beta)*(beta*(rs(T+1) + 1-ds)-1)+ beta^(T-1)*(beta*lambda(T+1).*(rs(T+1) + 1-ds)- lambda(T));

%EEcheck1 = 
%EEcheck2 = - lambda(T) +  beta*lambda(T+1).*(re(T+1) + 1-de) + ...
%    + mu*beta*vp(lu(T+1).*wu(T+1)./ws(T+1)).*der(T+1,1)

%foc(4*(T+1)+ T + 1: 4*(T+1)+2*T) = - lambda(1:T).*(1-betainf) +  beta*lambda(2:T+1).*(re(2:T+1) + 1-de) + ...
%    + mu*beta*vp(lu(2:T+1).*wu(2:T+1)./ws(2:T+1)).*der(2:T+1,1);
%check2 = foc(4*(T+1)+ T + 1: 4*(T+1)+2*T)
foc(4*(T+1)+ T + 1: 4*(T+1)+2*T-1) = - lambda(1:T-1) +  beta*lambda(2:T).*(re(2:T) + 1-de) + ...
    + mu*beta*vp(lu(2:T).*wu(2:T)./ws(2:T)).*der(2:T,1);
%foc(4*(T+1)+2*T) = - 1 +  beta*(re(T+1) + 1-de) + ...
%    + mu*beta/lambda(T+1)*vp(lu(T+1).*wu(T+1)./ws(T+1)).*der(T+1,1);
foc(4*(T+1)+2*T) = beta^T/(1-beta)*(- 1 +  beta*(re(T+1) + 1-de) + ...
    + mu*beta/lambda(T+1)*vp(lu(T+1).*wu(T+1)./ws(T+1)).*der(T+1,1))+ ...
    + beta^(T-1)*(mu*beta*vp(lu(T+1).*wu(T+1)./ws(T+1)).*der(T+1,1) - lambda(T) +  beta*lambda(T+1).*(re(T+1) + 1-de));

%feasibilities
foc(4*(T+1)+2*T+ 1:5*(T+1)+2*T) = G + Cu + Cs + [ks(2:T+1); ks(T+1)] + [ke(2:T+1); ke(T+1)] - ycomp([ks, ke, Lu, Ls]) - (1-ds)*ks - (1-de)*ke;

%define beta^t in vector form
betatemp = cumprod([1;beta*ones(T,1)]);
betavec = [betatemp(1:T); betatemp(T+1)/(1-beta)];

%IC 
foc(7*T+6,1) = betavec'*(u(cs) - v(ls) - u(cu) + v(lu.*wu./ws));
